@@ -515,16 +515,16 @@ impl Application {
 
         let mut transfer_pool = self.transfer_queue.create_command_pool()?;
         let transfer_buffer = transfer_pool.create_command_buffer(
-            Some(CommandBufferSemaphore::Timeline {
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: &self.transfer_timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value,
-            }),
-            Some(CommandBufferSemaphore::Timeline {
+            }],
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: &self.transfer_timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value + 1,
-            }),
+            }],
         )?;
 
         {
@@ -628,16 +628,16 @@ impl Application {
 
         let mut transfer_pool = self.transfer_queue.create_command_pool()?;
         let transfer_buffer = transfer_pool.create_command_buffer(
-            Some(CommandBufferSemaphore::Timeline {
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: &self.transfer_timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value,
-            }),
-            Some(CommandBufferSemaphore::Timeline {
+            }],
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: &self.transfer_timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value + 1,
-            }),
+            }],
         )?;
 
         {
@@ -666,11 +666,11 @@ impl Application {
         let frame = self.swapchain.next_frame(&self.presentation_semaphore)?;
 
         let graphics_buffer = self.graphics_command_pool.create_command_buffer(
-            None,
-            Some(CommandBufferSemaphore::Binary {
+            &[],
+            &[CommandBufferSemaphore::Binary {
                 semaphore: &self.render_semaphore,
                 stage: vk::PipelineStageFlags2KHR::COLOR_ATTACHMENT_OUTPUT_KHR,
-            }),
+            }],
         )?;
 
         let m_matrix =
