@@ -145,8 +145,8 @@ struct RayTracingApplication {
     uniforms: Vec<asche::Buffer>,
     sbt_stride_addresses: Vec<vk::StridedDeviceAddressRegionKHR>,
     _sbt: asche::Buffer,
-    tlas: Vec<TLAS>,
-    blas: Vec<BLAS>,
+    tlas: Vec<Tlas>,
+    blas: Vec<Blas>,
     models: Vec<Model>,
     extent: vk::Extent2D,
     render_fence: asche::Fence,
@@ -386,11 +386,11 @@ impl RayTracingApplication {
             vk::DescriptorBindingFlags::VARIABLE_DESCRIPTOR_COUNT
                 | vk::DescriptorBindingFlags::PARTIALLY_BOUND,
         ];
-        let mut layout_flags =
+        let layout_flags =
             vk::DescriptorSetLayoutBindingFlagsCreateInfoBuilder::new().binding_flags(&flags);
         let layout_info = vk::DescriptorSetLayoutCreateInfoBuilder::new()
             .bindings(&bindings)
-            .extend_from(&mut layout_flags);
+            .extend_from(&layout_flags);
         let raytracing_descriptor_set_layout =
             device.create_descriptor_set_layout("RT Descriptor Set Layout", layout_info)?;
 
@@ -404,11 +404,11 @@ impl RayTracingApplication {
         ];
         let flags = [vk::DescriptorBindingFlags::VARIABLE_DESCRIPTOR_COUNT
             | vk::DescriptorBindingFlags::PARTIALLY_BOUND];
-        let mut layout_flags =
+        let layout_flags =
             vk::DescriptorSetLayoutBindingFlagsCreateInfoBuilder::new().binding_flags(&flags);
         let layout_info = vk::DescriptorSetLayoutCreateInfoBuilder::new()
             .bindings(&vertex_bindings)
-            .extend_from(&mut layout_flags);
+            .extend_from(&layout_flags);
         let vertex_descriptor_set_layout =
             device.create_descriptor_set_layout("Vertex Descriptor Set Layout", layout_info)?;
 
@@ -422,11 +422,11 @@ impl RayTracingApplication {
         ];
         let flags = [vk::DescriptorBindingFlags::VARIABLE_DESCRIPTOR_COUNT
             | vk::DescriptorBindingFlags::PARTIALLY_BOUND];
-        let mut layout_flags =
+        let layout_flags =
             vk::DescriptorSetLayoutBindingFlagsCreateInfoBuilder::new().binding_flags(&flags);
         let layout_info = vk::DescriptorSetLayoutCreateInfoBuilder::new()
             .bindings(&index_bindings)
-            .extend_from(&mut layout_flags);
+            .extend_from(&layout_flags);
         let index_descriptor_set_layout =
             device.create_descriptor_set_layout("Index Descriptor Set Layout", layout_info)?;
 
@@ -865,12 +865,12 @@ impl RayTracingApplication {
 
         *timeline_value += 1;
         let command_buffer = pool.create_command_buffer(
-            None,
-            Some(CommandBufferSemaphore::Timeline {
+            &[],
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: *timeline_value,
-            }),
+            }],
         )?;
         {
             let encoder = command_buffer.record()?;
@@ -967,14 +967,14 @@ impl RayTracingApplication {
         let structures: Vec<vk::AccelerationStructureKHR> =
             self.tlas.iter().map(|x| x.structure.raw).collect();
 
-        let mut structure_info = vk::WriteDescriptorSetAccelerationStructureKHRBuilder::new()
+        let structure_info = vk::WriteDescriptorSetAccelerationStructureKHRBuilder::new()
             .acceleration_structures(&structures)
             .build();
         let mut tlas_write = vk::WriteDescriptorSetBuilder::new()
             .dst_set(self.raytracing_descriptor_set.raw)
             .dst_binding(0)
             .descriptor_type(vk::DescriptorType::ACCELERATION_STRUCTURE_KHR)
-            .extend_from(&mut structure_info);
+            .extend_from(&structure_info);
         tlas_write.descriptor_count = 1;
 
         // Camera Uniform
@@ -1101,21 +1101,27 @@ impl RayTracingApplication {
                 &self.device,
                 &format!("Model {} Vertex Buffer", id),
                 cast_slice(mesh.vertices.as_slice()),
-                vk::BufferUsageFlags::STORAGE_BUFFER | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
+                vk::BufferUsageFlags::ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_KHR
+                    | vk::BufferUsageFlags::STORAGE_BUFFER
+                    | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
                 vk::QueueFlags::GRAPHICS | vk::QueueFlags::COMPUTE,
             )?;
             let index_buffer = self.uploader.create_buffer_with_data(
                 &self.device,
                 &format!("Model {} Index Buffer", id),
                 cast_slice(mesh.indices.as_slice()),
-                vk::BufferUsageFlags::STORAGE_BUFFER | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
+                vk::BufferUsageFlags::ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_KHR
+                    | vk::BufferUsageFlags::STORAGE_BUFFER
+                    | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
                 vk::QueueFlags::GRAPHICS | vk::QueueFlags::COMPUTE,
             )?;
             let transform_buffer = self.uploader.create_buffer_with_data(
                 &self.device,
                 &format!("Model {} Transform Buffer", id),
                 cast_slice(&transform.matrix),
-                vk::BufferUsageFlags::STORAGE_BUFFER | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
+                vk::BufferUsageFlags::ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_KHR
+                    | vk::BufferUsageFlags::STORAGE_BUFFER
+                    | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
                 vk::QueueFlags::GRAPHICS | vk::QueueFlags::COMPUTE,
             )?;
 
@@ -1253,12 +1259,12 @@ impl RayTracingApplication {
     fn compact_blas(&mut self, max_sizes: &mut [u64], compacted_sizes: &[u64]) -> Result<()> {
         self.transfer_timeline_value += 1;
         let command_buffer = self.compute_pool.create_command_buffer(
-            None,
-            Some(CommandBufferSemaphore::Timeline {
+            &[],
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: &self.transfer_timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value,
-            }),
+            }],
         )?;
 
         let mut compacted_blas = Vec::with_capacity(self.blas.len());
@@ -1296,7 +1302,7 @@ impl RayTracingApplication {
         Ok(())
     }
 
-    fn create_new_blas(&self, id: &usize, compacted: u64) -> Result<BLAS> {
+    fn create_new_blas(&self, id: &usize, compacted: u64) -> Result<Blas> {
         let buffer = self.device.create_buffer(&asche::BufferDescriptor {
             name: &format!("Model {} BLAS Buffer", id),
             usage: vk::BufferUsageFlags::ACCELERATION_STRUCTURE_STORAGE_KHR
@@ -1317,7 +1323,7 @@ impl RayTracingApplication {
             .device
             .create_acceleration_structure("Model {} BLAS", &creation_info)?;
 
-        Ok(BLAS {
+        Ok(Blas {
             structure,
             _buffer: buffer,
         })
@@ -1340,16 +1346,16 @@ impl RayTracingApplication {
             Vec::with_capacity(self.models.len());
         for (id, _) in self.models.iter().enumerate() {
             let compute_buffer = self.compute_pool.create_command_buffer(
-                Some(CommandBufferSemaphore::Timeline {
+                &[CommandBufferSemaphore::Timeline {
                     semaphore: &self.transfer_timeline,
                     stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                     value: self.transfer_timeline_value,
-                }),
-                Some(CommandBufferSemaphore::Timeline {
+                }],
+                &[CommandBufferSemaphore::Timeline {
                     semaphore: &self.transfer_timeline,
                     stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                     value: self.transfer_timeline_value + 1,
-                }),
+                }],
             )?;
             self.transfer_timeline_value += 1;
 
@@ -1421,7 +1427,8 @@ impl RayTracingApplication {
             &self.device,
             "Model TLAS Instances",
             &cast_slice(instance_data.as_slice()),
-            vk::BufferUsageFlags::ACCELERATION_STRUCTURE_STORAGE_KHR
+            vk::BufferUsageFlags::ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_KHR
+                | vk::BufferUsageFlags::ACCELERATION_STRUCTURE_STORAGE_KHR
                 | vk::BufferUsageFlags::SHADER_DEVICE_ADDRESS,
             vk::QueueFlags::GRAPHICS | vk::QueueFlags::COMPUTE,
         )?;
@@ -1503,12 +1510,12 @@ impl RayTracingApplication {
 
         self.transfer_timeline_value += 1;
         let compute_buffer = self.compute_pool.create_command_buffer(
-            None,
-            Some(CommandBufferSemaphore::Timeline {
+            &[],
+            &[CommandBufferSemaphore::Timeline {
                 semaphore: &self.transfer_timeline,
                 stage: vk::PipelineStageFlags2KHR::NONE_KHR,
                 value: self.transfer_timeline_value,
-            }),
+            }],
         )?;
 
         {
@@ -1520,7 +1527,7 @@ impl RayTracingApplication {
         self.transfer_timeline
             .wait_for_value(self.transfer_timeline_value)?;
 
-        self.tlas.push(TLAS {
+        self.tlas.push(Tlas {
             structure,
             _buffer: buffer,
         });
@@ -1534,11 +1541,11 @@ impl RayTracingApplication {
         let frame = self.swapchain.next_frame(&self.presentation_semaphore)?;
 
         let command_buffer = self.graphics_pool.create_command_buffer(
-            None,
-            Some(CommandBufferSemaphore::Binary {
+            &[],
+            &[CommandBufferSemaphore::Binary {
                 semaphore: &self.render_semaphore,
                 stage: vk::PipelineStageFlags2KHR::COLOR_ATTACHMENT_OUTPUT_KHR,
-            }),
+            }],
         )?;
 
         {
@@ -1666,12 +1673,12 @@ impl RayTracingApplication {
     }
 }
 
-struct TLAS {
+struct Tlas {
     structure: asche::AccelerationStructure,
     _buffer: asche::Buffer,
 }
 
-struct BLAS {
+struct Blas {
     structure: asche::AccelerationStructure,
     _buffer: asche::Buffer,
 }
